@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,20 +42,23 @@ Breton_Default_Firefox_esr
    <ja>Breton localisation of Firefox ESR</ja>
    <kk>Breton localisation of Firefox ESR</kk>
    <ko>Breton localisation of Firefox ESR</ko>
+   <ku>Breton localisation of Firefox ESR</ku>
    <lt>Breton localisation of Firefox ESR</lt>
    <mk>Breton localisation of Firefox ESR</mk>
    <mr>Breton localisation of Firefox ESR</mr>
    <nb_NO>Breton localisation of Firefox ESR</nb_NO>
    <nb>Bretonsk lokaltilpassing av Firefox ESR</nb>
    <nl_BE>Breton localisation of Firefox ESR</nl_BE>
-   <nl>Breton localisation of Firefox ESR</nl>
+   <nl>Bretonse lokalisatie van Firefox ESR</nl>
+   <or>Breton localisation of Firefox ESR</or>
    <pl>Breton localisation of Firefox ESR</pl>
    <pt_BR>Bretão Localização para o Firefox ESR</pt_BR>
    <pt>Bretão Localização para Firefox ESR</pt>
    <ro>Breton localisation of Firefox ESR</ro>
    <ru>Breton localisation of Firefox ESR</ru>
    <sk>Breton localisation of Firefox ESR</sk>
-   <sl>Breton localisation of Firefox ESR</sl>
+   <sl>Bretonske krajevne nastavitve za Firefox ESR</sl>
+   <so>Breton localisation of Firefox ESR</so>
    <sq>Përkthimi i Firefox-it ESR në bretonisht</sq>
    <sr>Breton localisation of Firefox ESR</sr>
    <sv>Bretonsk  lokalisering av Firefox ESR</sv>
