@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,13 +42,15 @@ French
    <ja>Hunspell 用フランス語辞書</ja>
    <kk>French dictionary for hunspell</kk>
    <ko>French dictionary for hunspell</ko>
+   <ku>French dictionary for hunspell</ku>
    <lt>French dictionary for hunspell</lt>
    <mk>French dictionary for hunspell</mk>
    <mr>French dictionary for hunspell</mr>
    <nb_NO>French dictionary for hunspell</nb_NO>
    <nb>Fransk ordliste for hunspell</nb>
    <nl_BE>French dictionary for hunspell</nl_BE>
-   <nl>French dictionary for hunspell</nl>
+   <nl>Frans woordenboek voor hunspell</nl>
+   <or>French dictionary for hunspell</or>
    <pl>French dictionary for hunspell</pl>
    <pt_BR>Dicionário Francês para o hunspell (corretor ortográfico e analisador morfológico)</pt_BR>
    <pt>Dicionário Francês para hunspell</pt>
@@ -56,6 +58,7 @@ French
    <ru>French dictionary for hunspell</ru>
    <sk>French dictionary for hunspell</sk>
    <sl>Francoski slovar za hunspell</sl>
+   <so>French dictionary for hunspell</so>
    <sq>Fjalor frëngjisht për hunspell</sq>
    <sr>French dictionary for hunspell</sr>
    <sv>Fransk ordbok för hunspell</sv>
