@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ Norwegian_Nynorsk_Default_Firefox_esr
    <ja>ニーノシュク版 Firefox ESR</ja>
    <kk>Norwegian_nynorsk Language localisation of Firefox ESR</kk>
    <ko>Norwegian_nynorsk Language localisation of Firefox ESR</ko>
+   <ku>Norwegian_nynorsk Language localisation of Firefox ESR</ku>
    <lt>Norwegian_nynorsk Language localisation of Firefox ESR</lt>
    <mk>Norwegian_nynorsk Language localisation of Firefox ESR</mk>
    <mr>Norwegian_nynorsk Language localisation of Firefox ESR</mr>
@@ -49,6 +50,7 @@ Norwegian_Nynorsk_Default_Firefox_esr
    <nb>Nynorsk lokaltilpassing av Firefox ESR</nb>
    <nl_BE>Norwegian_nynorsk Language localisation of Firefox ESR</nl_BE>
    <nl>Norwegian_nynorsk Language localisation of Firefox ESR</nl>
+   <or>Norwegian_nynorsk Language localisation of Firefox ESR</or>
    <pl>Norwegian_nynorsk Language localisation of Firefox ESR</pl>
    <pt_BR>Novo Norueguês Localização para o Firefox ESR</pt_BR>
    <pt>Norueguês_nynorsk Localização para Firefox ESR</pt>
@@ -56,6 +58,7 @@ Norwegian_Nynorsk_Default_Firefox_esr
    <ru>Norwegian_nynorsk Language localisation of Firefox ESR</ru>
    <sk>Norwegian_nynorsk Language localisation of Firefox ESR</sk>
    <sl>Norveške nynorsk krajevne nastavitve za Firefox ESR</sl>
+   <so>Norwegian_nynorsk Language localisation of Firefox ESR</so>
    <sq>Përkthimi i Firefox-it ESR në norvegjishte ninorsk</sq>
    <sr>Norwegian_nynorsk Language localisation of Firefox ESR</sr>
    <sv>Norsk_nynorsk Språk lokalisering av Firefox ESR</sv>
