@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ Polish_Firefox
    <ja>ポーランド語版 Firefox</ja>
    <kk>Polish localisation of Firefox</kk>
    <ko>Polish localisation of Firefox</ko>
+   <ku>Polish localisation of Firefox</ku>
    <lt>Polish localisation of Firefox</lt>
    <mk>Polish localisation of Firefox</mk>
    <mr>Polish localisation of Firefox</mr>
@@ -49,6 +50,7 @@ Polish_Firefox
    <nb>Polsk lokaltilpassing av Firefox</nb>
    <nl_BE>Polish localisation of Firefox</nl_BE>
    <nl>Poolse lokalisatie van Firefox</nl>
+   <or>Polish localisation of Firefox</or>
    <pl>Polska lokalizacja przeglądarki Firefox</pl>
    <pt_BR>Polonês Localização para o Firefox</pt_BR>
    <pt>Polaco Localização para Firefox</pt>
@@ -56,6 +58,7 @@ Polish_Firefox
    <ru>Польская локализация Firefox</ru>
    <sk>Polish localisation of Firefox</sk>
    <sl>Poljske krajevne nastavitve za Firefox</sl>
+   <so>Polish localisation of Firefox</so>
    <sq>Përkthimi i Firefox-it në polonisht</sq>
    <sr>Polish localisation of Firefox</sr>
    <sv>Polsk lokalisering av Firefox</sv>
