@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ Romanian_Thunderbird
    <ja>Thunderbird のルーマニア語版</ja>
    <kk>Romanian localisation of Thunderbird</kk>
    <ko>Romanian localisation of Thunderbird</ko>
+   <ku>Romanian localisation of Thunderbird</ku>
    <lt>Romanian localisation of Thunderbird</lt>
    <mk>Romanian localisation of Thunderbird</mk>
    <mr>Romanian localisation of Thunderbird</mr>
@@ -49,6 +50,7 @@ Romanian_Thunderbird
    <nb>Romansk lokaltilpassing av Thunderbird</nb>
    <nl_BE>Romanian localisation of Thunderbird</nl_BE>
    <nl>Roemeense lokalisatie van Thunderbird</nl>
+   <or>Romanian localisation of Thunderbird</or>
    <pl>Rumuńska lokalizacja Thunderbirda</pl>
    <pt_BR>Romeno Localização para o Thunderbird</pt_BR>
    <pt>Romeno Localização para Thunderbird</pt>
@@ -56,6 +58,7 @@ Romanian_Thunderbird
    <ru>Romanian localisation of Thunderbird</ru>
    <sk>Romanian localisation of Thunderbird</sk>
    <sl>Romunske krajevne nastavitve za Thunderbird</sl>
+   <so>Romanian localisation of Thunderbird</so>
    <sq>Përkthimi i Thunderbird-it në rumanisht</sq>
    <sr>Romanian localisation of Thunderbird</sr>
    <sv>Rumänsk lokalisering av Thunderbird </sv>
