@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ Swiss (German)
    <ja>Hunspell 用スイス語（ドイツ）辞書</ja>
    <kk>Swiss (German) dictionary for hunspell</kk>
    <ko>Swiss (German) dictionary for hunspell</ko>
+   <ku>Swiss (German) dictionary for hunspell</ku>
    <lt>Swiss (German) dictionary for hunspell</lt>
    <mk>Swiss (German) dictionary for hunspell</mk>
    <mr>Swiss (German) dictionary for hunspell</mr>
@@ -49,6 +50,7 @@ Swiss (German)
    <nb>Sveitsisk (tysk) ordliste for hunspell</nb>
    <nl_BE>Swiss (German) dictionary for hunspell</nl_BE>
    <nl>Swiss (German) dictionary for hunspell</nl>
+   <or>Swiss (German) dictionary for hunspell</or>
    <pl>Swiss (German) dictionary for hunspell</pl>
    <pt_BR>Dicionário Suíço (Alemão) para o hunspell (corretor ortográfico e analisador morfológico)</pt_BR>
    <pt>Dicionário Suiço (Alemão) para hunspell</pt>
@@ -56,6 +58,7 @@ Swiss (German)
    <ru>Swiss (German) dictionary for hunspell</ru>
    <sk>Swiss (German) dictionary for hunspell</sk>
    <sl>Švicarski (nemški) slovar za hunspell</sl>
+   <so>Swiss (German) dictionary for hunspell</so>
    <sq>Fjalor zviceranishte (gjermanisht) për hunspell</sq>
    <sr>Swiss (German) dictionary for hunspell</sr>
    <sv>Schweizisk (Tysk) ordbok för hunspell</sv>
