@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ Ukrainian_Fonts
    <ja>ウクライナ語のフォントパッケージ</ja>
    <kk>Ukrainian fonts packages</kk>
    <ko>Ukrainian fonts packages</ko>
+   <ku>Ukrainian fonts packages</ku>
    <lt>Ukrainian fonts packages</lt>
    <mk>Ukrainian fonts packages</mk>
    <mr>Ukrainian fonts packages</mr>
@@ -49,6 +50,7 @@ Ukrainian_Fonts
    <nb>Pakke med ukrainske skrifttyper</nb>
    <nl_BE>Ukrainian fonts packages</nl_BE>
    <nl>Oekraïense font pakketten</nl>
+   <or>Ukrainian fonts packages</or>
    <pl>pakiety z ukraińskimi fontami (czcionkami)</pl>
    <pt_BR>Pacotes de Fontes Ucraniano</pt_BR>
    <pt>Ucraniano Pacotes de fontes</pt>
@@ -56,6 +58,7 @@ Ukrainian_Fonts
    <ru>Ukrainian fonts packages</ru>
    <sk>Ukrainian fonts packages</sk>
    <sl>Ukrajinski paketi pisav</sl>
+   <so>Ukrainian fonts packages</so>
    <sq>Paketa shkronjash për ukrainishten</sq>
    <sr>Ukrainian fonts packages</sr>
    <sv>Ukrainska typsnitts-paket</sv>
