@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ Audacity
    <ja>マルチトラック・オーディオエディター</ja>
    <kk>a multi-track audio editor</kk>
    <ko>a multi-track audio editor</ko>
+   <ku>a multi-track audio editor</ku>
    <lt>a multi-track audio editor</lt>
    <mk>a multi-track audio editor</mk>
    <mr>a multi-track audio editor</mr>
@@ -49,6 +50,7 @@ Audacity
    <nb>lydredigering med flere spor</nb>
    <nl_BE>a multi-track audio editor</nl_BE>
    <nl>een multi-track audio editor</nl>
+   <or>a multi-track audio editor</or>
    <pl>wielościeżkowy edytor audio</pl>
    <pt_BR>Editor de áudio multifaixa</pt_BR>
    <pt>Editor de áudio multi-faixa</pt>
@@ -56,6 +58,7 @@ Audacity
    <ru>Многодорожечный аудио редактор</ru>
    <sk>viackanálový audio editor</sk>
    <sl>večstezni urejevalnik zvoka</sl>
+   <so>a multi-track audio editor</so>
    <sq>Një përpunues audio me shumë pista</sq>
    <sr>a multi-track audio editor</sr>
    <sv>en flerspårs ljudredigerare</sv>
