@@ -83,7 +83,7 @@ all
 
 <install_package_names>
 gamine
-gcompris
+gcompris-qt
 tuxpaint
 </install_package_names>
 
@@ -95,7 +95,7 @@ tuxpaint
 
 <uninstall_package_names>
 gamine
-gcompris
+gcompris-qt
 tuxpaint
 </uninstall_package_names>
 </app>
