@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -6,7 +6,7 @@ Development
 </category>
 
 <name>
-QT5 Dev Enviroment
+QT5 Dev Environment
 </name>
 
 <description>
@@ -42,6 +42,7 @@ QT5 Dev Enviroment
    <ja>QT5 開発環境</ja>
    <kk>QT5 Development Environment</kk>
    <ko>QT5 Development Environment</ko>
+   <ku>QT5 Development Environment</ku>
    <lt>QT5 plėtojimo aplinka</lt>
    <mk>QT5 Development Environment</mk>
    <mr>QT5 Development Environment</mr>
@@ -49,6 +50,7 @@ QT5 Dev Enviroment
    <nb>Utviklingsmiljø for Qt 5</nb>
    <nl_BE>QT5 Development Environment</nl_BE>
    <nl>QT5 Ontwikkelingsomgeving</nl>
+   <or>QT5 Development Environment</or>
    <pl>środowisko programistyczne QT5</pl>
    <pt_BR>Ambiente de Desenvolvimento QT5</pt_BR>
    <pt>Ambiente de Desenvolvimento QT5</pt>
@@ -56,6 +58,7 @@ QT5 Dev Enviroment
    <ru>Среда разработки под QT-5</ru>
    <sk>QT5 Development Environment</sk>
    <sl>QT5 razvojno okolje</sl>
+   <so>QT5 Development Environment</so>
    <sq>Mjedis Zhvillimesh QT5</sq>
    <sr>QT5 Development Environment</sr>
    <sv>QT5 Utvecklingsmiljö</sv>
@@ -80,8 +83,9 @@ all
 
 <install_package_names>
 qtcreator
-qt5-default
+qttools5-dev
 qttools5-dev-tools
+qtdeclarative5-dev-tools
 </install_package_names>
 
 
@@ -92,7 +96,8 @@ qttools5-dev-tools
 
 <uninstall_package_names>
 qtcreator
-qt5-default
+qttools5-dev
 qttools5-dev-tools
+qtdeclarative5-dev-tools
 </uninstall_package_names>
 </app>
