@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ Streamlight
    <ja>任意のアプリやブラウザでリンクを選択して、Youtubeビデオのストリーミングまたはダウンロードができます</ja>
    <kk>Stream or download Youtube videos by selecting links in any app or browser</kk>
    <ko>Stream or download Youtube videos by selecting links in any app or browser</ko>
+   <ku>Stream or download Youtube videos by selecting links in any app or browser</ku>
    <lt>Stream or download Youtube videos by selecting links in any app or browser</lt>
    <mk>Stream or download Youtube videos by selecting links in any app or browser</mk>
    <mr>Stream or download Youtube videos by selecting links in any app or browser</mr>
@@ -49,6 +50,7 @@ Streamlight
    <nb>Strøm eller last ned Youtube-videoer ved å velge lenker i et program eller nettleser</nb>
    <nl_BE>Stream or download Youtube videos by selecting links in any app or browser</nl_BE>
    <nl>Stream or download Youtube videos by selecting links in any app or browser</nl>
+   <or>Stream or download Youtube videos by selecting links in any app or browser</or>
    <pl>Stream or download Youtube videos by selecting links in any app or browser</pl>
    <pt_BR>Transmita ou baixe vídeos do Youtube selecionando links em qualquer aplicativo ou navegador de internet</pt_BR>
    <pt>Ver ou transferir videos do Youtube, ao selecionar ligações em qualquer aplicação ou navegador de Internet</pt>
@@ -56,6 +58,7 @@ Streamlight
    <ru>Stream or download Youtube videos by selecting links in any app or browser</ru>
    <sk>Stream or download Youtube videos by selecting links in any app or browser</sk>
    <sl>Pretakanje ali prenos Youtube videov preko izbire povezav v poljubni aplikaciji ali brskalniku</sl>
+   <so>Stream or download Youtube videos by selecting links in any app or browser</so>
    <sq>SHihni ose shkarkoni video Youtube duke përzgjedhur lidhje në çfarëdo aplikacioni ose shfletuesi</sq>
    <sr>Stream or download Youtube videos by selecting links in any app or browser</sr>
    <sv>Strömma eller ladda ner Youtube videos genom att välja länkar i alla appar eller webbläsare</sv>
